Learn R Programming

ibb (version 0.0.2)

get_iski_call_center_complaint_stats: Water Outage Complaints and Response Numbers by District in 2019

Description

Contains information on the number of complaints and responses to water outages and responses from all districts and neighborhoods across Istanbul in 2019, from the Istanbul Water and Sewerage Administration (<U+0130>SK<U+0130>) call center.

Usage

get_iski_call_center_complaint_stats(
  params = list(limit = Sys.getenv("IBB_QUERY_LIMIT"))
)

Arguments

params

List of parameters

Examples

Run this code
# NOT RUN {
get_iski_call_center_complaint_stats(params = list(limit = 5))
# }

Run the code above in your browser using DataLab